@@ -309,7 +309,7 @@ void sighandler(int sig) {
 
 int print_help(char *msg) {
 	fprintf(stderr, "Usage: tcpcgi -H host -f file -d dest [-P port] [-p port] [-m time]\n");
-	fprintf(stderr, "              [-x time] [-t time] [-b amt] [-riglvh]\n");
+	fprintf(stderr, "              [-x time] [-t time] [-b amt] [-rigluvh]\n");
 	fprintf(stderr, "    Options:\n");
 	fprintf(stderr, "         -H host      HTTP Server which has tcpcgi.cgi.\n");
 	fprintf(stderr, "         -f file      Full URL-relative on HTTP server to tcpcgi.cgi,\n");
@@ -337,6 +337,7 @@ int print_help(char *msg) {
 	fprintf(stderr, "                      the default).\n");
 	fprintf(stderr, "         -l           Bind to %s only for listening (%s is the\n", local_only?"ALL":"LOCALHOST", local_only?"LOCAL":"ALL");
 	fprintf(stderr, "                      default).\n");
+	fprintf(stderr, "         -u           Use UDP instead of TCP.\n");
 	fprintf(stderr, "         -v           Print version (%s) and exit.\n", TCPCGI_VERSION);
 	fprintf(stderr, "         -h           This help information.\n");
 	if (msg) {
@@ -376,11 +377,12 @@ int main(int argc, char **argv) {
 	int poll_backoff=2;
 	int poll_backoff_reset=0, poll_backoff_ireset=0;
 	int http_port=80;
+	int proto_type=SOCK_STREAM;
 #ifndef DEBUG
 	pid_t chpid;
 #endif
 
-	while ((ch=getopt(argc, argv, "H:f:P:p:d:m:x:t:b:vgrilh"))!=-1) {
+	while ((ch=getopt(argc, argv, "H:f:P:p:d:m:x:t:b:vgriulh"))!=-1) {
 		switch (ch) {
 			case 'H':
 				http_host=strdup(optarg);
@@ -435,6 +437,9 @@ int main(int argc, char **argv) {
 			case 'l':
 				local_only=!local_only;
 				break;
+			case 'u':
+				proto_type=(proto_type==SOCK_STREAM)?SOCK_DGRAM:SOCK_STREAM;
+				break;
 			case ':':
 			case '?':
 			case 'h':
@@ -460,7 +465,7 @@ int main(int argc, char **argv) {
 
 	signal(SIGALRM, sighandler);
 	signal(SIGPIPE, SIG_IGN);
-	masterfd=createlisten(listen_port, local_only);
+	masterfd=createlisten(listen_port, local_only, proto_type);
 	if (masterfd<0) {
 		PERROR("createlisten()");
 		return(1);
