@@ -44,10 +44,10 @@ extern int errno;
 /*
  *	Create a listening port on tcp port PORT
  */
-int createlisten(int port, int localonly) {
+int createlisten(int port, int localonly,int type) {
 	struct sockaddr_in localname;
 	int sockFd;
-	sockFd=socket(AF_INET,SOCK_STREAM,IPPROTO_IP);
+	sockFd=socket(AF_INET,type,IPPROTO_IP);
 	localname.sin_family=AF_INET;
 	localname.sin_port=htons(port);
 	localname.sin_addr.s_addr=htonl((localonly)?(INADDR_LOOPBACK):(INADDR_ANY));
@@ -65,7 +65,7 @@ void closeconnection(int sockfd) {
 	close(sockfd);
 }
 
-int createconnection_tcp(char *host, int port) {
+int createconnection(char *host, int port, int type) {
 	int sockid;
 	struct hostent *hostinfo;
 	struct sockaddr_in sock;
@@ -81,7 +81,7 @@ int createconnection_tcp(char *host, int port) {
 	}
 	sock.sin_family=AF_INET;
 	sock.sin_port=htons(port);
-	if ((sockid=socket(AF_INET, SOCK_STREAM, 0))<0)
+	if ((sockid=socket(AF_INET, type, 0))<0)
 		return(-1);
 	if (connect(sockid, (struct sockaddr *) &sock, sizeof(sock))<0) {
 		close(sockid);
@@ -89,9 +89,13 @@ int createconnection_tcp(char *host, int port) {
 	}
 	return(sockid);
 }
+int createconnection_tcp(char *host, int port) {
+	return(createconnection(host,port,SOCK_STREAM));
+}
 
 #else
 int createlisten(int port, int localonly) { return(-1); }
 void closeconnection(int sockfd) { return; }
+int createconnection(char *host, int port, int type) { return(-1); }
 int createconnection_tcp(char *host, int port) { return(-1); }
 #endif
